@@ -12,9 +12,11 @@ my $redis = AnyEvent::Redis::RipeRedis->new(
   host => 'localhost',
   port => '6379',
   password => 'yourpass',
+
   on_connect => sub {
     print "Connected to Redis server\n";
   },
+
   on_disconnect => sub {
     print "Disconnected from Redis server\n";
   },
@@ -22,15 +24,18 @@ my $redis = AnyEvent::Redis::RipeRedis->new(
 
 # Execute Lua script
 $redis->eval_cached( 'return { KEYS[1], KEYS[2], ARGV[1], ARGV[2] }',
-    2, 'key1', 'key2', 'first', 'second', {
-  on_done => sub {
-    my $data = shift;
-    foreach my $val ( @{$data}  ) {
-      print "$val\n";
-    }
-    $cv->send();
+    2, 'key1', 'key2', 'first', 'second',
+  { on_done => sub {
+      my $reply = shift;
+
+      foreach my $val ( @{$reply}  ) {
+        print "$val\n";
+      }
+
+      $cv->send();
+    },
   }
-} );
+);
 
 $cv->recv();
 
